"""Index of XLSForm file paths, including Entities tab."""

import os

xlsforms_with_entities_path = os.path.dirname(os.path.abspath(__file__))

registration_form = f"{xlsforms_with_entities_path}/registration_form.xls"
